@@ -3,9 +3,11 @@ Main interface for cloudhsm service type definitions.
 
 Usage::
 
-    from mypy_boto3.cloudhsm.type_defs import TagTypeDef
+    ```python
+    from mypy_boto3_cloudhsm.type_defs import TagTypeDef
 
     data: TagTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
@@ -14,6 +16,7 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
